==> connector-service-1.0.2-zds-20220713.084230-4-sources.jar: com/bizvane/connectorservice/entity/zds/CouponDefinitionListRequestVo.java <==
package com.bizvane.connectorservice.entity.zds;

import com.bizvane.connectorservice.entity.base.ZdsBaseModel;

import java.util.List;

public class CouponDefinitionListRequestVo extends ZdsBaseModel {

    //券定义ID
    private List<String> erpCouponDefinitionCodeList;
    //当前页数
    private Integer pageNum;
    //每页数量
    private Integer num;
    //券定义名称
    private String couponName;
    //券定义状态 0正常可使用；-1已冻结，不可使用；-2 已过期
    private String status;
    //门店Code
    private String StoreCode;

    public List<String> getErpCouponDefinitionCodeList() {
        return erpCouponDefinitionCodeList;
    }

    public void setErpCouponDefinitionCodeList(List<String> erpCouponDefinitionCodeList) {
        this.erpCouponDefinitionCodeList = erpCouponDefinitionCodeList;
    }

    public Integer getPageNum() {
        return pageNum;
    }

    public void setPageNum(Integer pageNum) {
        this.pageNum = pageNum;
    }

    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getStoreCode() {
        return StoreCode;
    }

    public void setStoreCode(String storeCode) {
        StoreCode = storeCode;
    }
}

==> connector-service-1.0.4-zds-20230523.095522-2-sources.jar: com/bizvane/connectorservice/entity/zds/CouponDefinitionListRequestVo.java <==
package com.bizvane.connectorservice.entity.zds;

import com.bizvane.connectorservice.entity.base.ZdsBaseModel;

import java.util.List;

public class CouponDefinitionListRequestVo extends ZdsBaseModel {

    //券定义ID
    private List<String> erpCouponDefinitionCodeList;
    //当前页数
    private Integer pageNum;
    //每页数量
    private Integer num;
    //券定义名称
    private String couponName;
    //券定义状态 0正常可使用；-1已冻结，不可使用；-2 已过期
    private String status;
    //门店Code
    private String storeCode;

    //券模板剩余数量过滤类型 1.查询优惠券剩余数量大于0
    private Integer remainNumFilterType;

    public List<String> getErpCouponDefinitionCodeList() {
        return erpCouponDefinitionCodeList;
    }

    public void setErpCouponDefinitionCodeList(List<String> erpCouponDefinitionCodeList) {
        this.erpCouponDefinitionCodeList = erpCouponDefinitionCodeList;
    }

    public Integer getPageNum() {
        return pageNum;
    }

    public void setPageNum(Integer pageNum) {
        this.pageNum = pageNum;
    }

    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getStoreCode() {
        return storeCode;
    }

    public void setStoreCode(String storeCode) {
        this.storeCode = storeCode;
    }

    public Integer getRemainNumFilterType() {
        return remainNumFilterType;
    }

    public void setRemainNumFilterType(Integer remainNumFilterType) {
        this.remainNumFilterType = remainNumFilterType;
    }
}
